<?php
/**
 * The exception handler for this application
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

// Our own exception handler
function __exceptionHandler (FrameworkException $e) {
	// Call the app_die() method
	ApplicationEntryPoint::app_die(sprintf("[Main:] The application <strong>%s</strong> (<strong>%s</strong>) has been terminated due to a thrown exception: <strong>%s: <span id=\"debug_exception\">%s</em></strong>. Backtrace: <div id=\"debug_backtrace\">%s</div>",
		ApplicationHelper::getInstance()->getAppName(),
		ApplicationHelper::getInstance()->getAppShortName(),
		$e->__toString(),
		$e->getMessage(),
		$e->getPrintableBackTrace()
	));
}

// Set the new handler
set_exception_handler('__exceptionHandler');

// Error handler
function __errorHandler ($errno, $errstr, $errfile, $errline, array $errcontext) {
	// Construct the message
	$message = sprintf("File: <span id=\"debug_file\">%s</span>, Line: <span id=\"debug_line\">%s</span>, Code: <span id=\"debug_code\">%s</span>, Message: <span id=\"debug_message\">%s</span>",
		basename($errfile),
		$errline,
		$errno,
		$errstr
	);

	// Throw an exception here
	throw new FatalErrorException($message, BaseFrameworkSystem::EXCEPTION_FATAL_ERROR);
}

// Set error handler
set_error_handler('__errorHandler');

// [EOF]
?>
